@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the plugins of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qwaylandtouch_p.h"
 #include "qwaylandinputdevice_p.h"
@@ -59,6 +23,11 @@ QWaylandTouchExtension::QWaylandTouchExtension(QWaylandDisplay *display, uint32_
 {
 }
 
+QWaylandTouchExtension::~QWaylandTouchExtension()
+{
+    qt_touch_extension_destroy(object());
+}
+
 void QWaylandTouchExtension::registerDevice(int caps)
 {
     // TODO number of touchpoints, actual name and ID
@@ -143,12 +112,12 @@ void QWaylandTouchExtension::touch_extension_touch(uint32_t time,
 void QWaylandTouchExtension::sendTouchEvent()
 {
     // Copy all points, that are in the previous but not in the current list, as stationary.
-    for (int i = 0; i < mPrevTouchPoints.count(); ++i) {
+    for (int i = 0; i < mPrevTouchPoints.size(); ++i) {
         const QWindowSystemInterface::TouchPoint &prevPoint(mPrevTouchPoints.at(i));
         if (prevPoint.state == QEventPoint::Released)
             continue;
         bool found = false;
-        for (int j = 0; j < mTouchPoints.count(); ++j)
+        for (int j = 0; j < mTouchPoints.size(); ++j)
             if (mTouchPoints.at(j).id == prevPoint.id) {
                 found = true;
                 break;
@@ -168,14 +137,14 @@ void QWaylandTouchExtension::sendTouchEvent()
     QWindowSystemInterface::handleTouchEvent(mTargetWindow, mTimestamp, mTouchDevice, mTouchPoints);
 
     QEventPoint::States states = {};
-    for (int i = 0; i < mTouchPoints.count(); ++i)
+    for (int i = 0; i < mTouchPoints.size(); ++i)
         states |= mTouchPoints.at(i).state;
 
     if (mFlags & QT_TOUCH_EXTENSION_FLAGS_MOUSE_FROM_TOUCH) {
         const bool firstPress = states == QEventPoint::Pressed;
         if (firstPress)
             mMouseSourceId = mTouchPoints.first().id;
-        for (int i = 0; i < mTouchPoints.count(); ++i) {
+        for (int i = 0; i < mTouchPoints.size(); ++i) {
             const QWindowSystemInterface::TouchPoint &tp(mTouchPoints.at(i));
             if (tp.id == mMouseSourceId) {
                 const bool released = tp.state == QEventPoint::Released;
